@@ -188,7 +188,7 @@ void RegisterBlasrOptions(CommandLineParser& clp, MappingParameters& params)
     clp.RegisterIntOption("-scoreType", &params.scoreType, "",
                           CommandLineParser::NonNegativeInteger);
     clp.RegisterFlagOption("h", &params.printVerboseHelp, "");
-    clp.RegisterFlagOption("-help", &params.printDiscussion, "");
+    clp.RegisterFlagOption("-help", &params.printVerboseHelp, "");
     clp.RegisterFloatOption("-accuracyPrior", &params.readAccuracyPrior, "",
                             CommandLineParser::NonNegativeFloat);
     // holeNumberRangesStr is a string of comma-delimited hole number ranges, such as '1,2,3,10-15'.
@@ -225,7 +225,7 @@ void RegisterBlasrOptions(CommandLineParser& clp, MappingParameters& params)
 
 const std::string BlasrHelp(MappingParameters& params)
 {
-    std::stringstream helpStream;
+    std::ostringstream helpStream;
     helpStream
         << "   Options for blasr " << std::endl
         << "   Basic usage: 'blasr reads.{bam|fasta|bax.h5|fofn} genome.fasta [-options] "
@@ -629,13 +629,65 @@ const std::string BlasrHelp(MappingParameters& params)
         << "Bioinformatics 2012, 13:238." << std::endl
         << "Please report any bugs to "
         << "'https://github.com/PacificBiosciences/blasr/issues'." << std::endl
+        << std::endl
+        << std::endl
+        << "DISCUSSION " << std::endl
+        << "  blasr is a read mapping program that maps reads to positions " << std::endl
+        << "  in a genome by clustering short exact matches between the read and" << std::endl
+        << "  the genome, and scoring clusters using alignment. The matches are" << std::endl
+        << "  generated by searching all suffixes of a read against the genome" << std::endl
+        << "  using a suffix array. Global chaining methods are used to score " << std::endl
+        << "  clusters of matches." << std::endl
+        << std::endl
+        << "  The only required inputs to blasr are a file of reads and a" << std::endl
+        << "  reference genome.  It is exremely useful to have read filtering" << std::endl
+        << "  information, and mapping runtime may decrease substantially when a" << std::endl
+        << "  precomputed suffix array index on the reference sequence is" << std::endl
+        << "  specified." << std::endl
+        << "  " << std::endl
+        << "  Although reads may be input in FASTA format, the recommended input is" << std::endl
+        << "  PacBio BAM files because these contain quality value" << std::endl
+        << "  information that is used in the alignment and produces higher quality" << std::endl
+        << "  variant detection." << std::endl
+        << "  Although alignments can be output in various formats, the recommended " << std::endl
+        << "  output format is PacBio BAM." << std::endl
+        << "  Support to bax.h5 and plx.h5 files will be DEPRECATED." << std::endl
+        << "  Support to region tables for h5 files will be DEPRECATED." << std::endl
+        << "  " << std::endl
+        << "  When suffix array index of a genome is not specified, the suffix array is"
+        << std::endl
+        << "  built before producing alignment.   This may be prohibitively slow" << std::endl
+        << "  when the genome is large (e.g. Human).  It is best to precompute the" << std::endl
+        << "  suffix array of a genome using the program sawriter, and then specify" << std::endl
+        << "  the suffix array on the command line using -sa genome.fa.sa." << std::endl
+        << "  " << std::endl
+        << "  The optional parameters are roughly divided into three categories:" << std::endl
+        << "  control over anchoring, alignment scoring, and output. " << std::endl
+        << "  " << std::endl
+        << "  The default anchoring parameters are optimal for small genomes and" << std::endl
+        << "  samples with up to 5% divergence from the reference genome.  The main" << std::endl
+        << "  parameter governing speed and sensitivity is the -minMatch parameter." << std::endl
+        << "  For human genome alignments, a value of 11 or higher is recommended.  " << std::endl
+        << "  Several methods may be used to speed up alignments, at the expense of" << std::endl
+        << "  possibly decreasing sensitivity.  " << std::endl
+        << "  " << std::endl
+        << "  Regions that are too repetitive may be ignored during mapping by" << std::endl
+        << "  limiting the number of positions a read maps to with the" << std::endl
+        << "  -maxAnchorsPerPosition option.  Values between 500 and 1000 are effective"
+        << std::endl
+        << "  in the human genome." << std::endl
+        << "  " << std::endl
+        << "  For small genomes such as bacterial genomes or BACs, the default parameters "
+        << std::endl
+        << "  are sufficient for maximal sensitivity and good speed." << std::endl
+        << std::endl
         << std::endl;
     return helpStream.str();
 }
 
 const std::string BlasrConciseHelp(void)
 {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "blasr - a program to map reads to a genome" << std::endl
        << " usage: blasr reads genome " << std::endl
        << " Run with -h for a list of commands " << std::endl
@@ -652,7 +704,7 @@ const std::string BlasrConciseHelp(void)
 
 const std::string BlasrSummaryHelp(void)
 {
-    std::stringstream ss;
+    std::ostringstream ss;
     ss << "   Basic usage: 'blasr reads.{bam|fasta|bax.h5|fofn} genome.fasta [-options] "
        << std::endl
        << " [option]\tDescription (default_value)." << std::endl
@@ -674,93 +726,3 @@ const std::string BlasrSummaryHelp(void)
        << std::endl;
     return ss.str();
 }
-
-const std::string BlasrDiscussion(void)
-{
-    std::stringstream ss;
-    ss << "NAME" << std::endl
-       << "         blasr - Map SMRT Sequences to a reference genome." << std::endl
-       << std::endl
-       << "SYNOPSIS" << std::endl
-       << "         blasr reads.bam genome.fasta --bam --out out.bam" << std::endl
-       << std::endl
-       << "         blasr reads.fasta genome.fasta " << std::endl
-       << std::endl
-       << "         blasr reads.fasta genome.fasta --sa genome.fasta.sa" << std::endl
-       << std::endl
-       << "         blasr reads.bax.h5 genome.fasta [--sa genome.fasta.sa] " << std::endl
-       << std::endl
-       << "         blasr reads.bax.h5 genome.fasta --sa genome.fasta.sa --maxScore 100 --minMatch "
-          "15 ... "
-       << std::endl
-       << std::endl
-       << "         blasr reads.bax.h5 genome.fasta --sa genome.fasta.sa --nproc 24 --out "
-          "alignment.out ... "
-       << std::endl
-       << std::endl
-       << "DESCRIPTION " << std::endl
-       << "  blasr is a read mapping program that maps reads to positions " << std::endl
-       << "  in a genome by clustering short exact matches between the read and" << std::endl
-       << "  the genome, and scoring clusters using alignment. The matches are" << std::endl
-       << "  generated by searching all suffixes of a read against the genome" << std::endl
-       << "  using a suffix array. Global chaining methods are used to score " << std::endl
-       << "  clusters of matches." << std::endl
-       << std::endl
-       << "  The only required inputs to blasr are a file of reads and a" << std::endl
-       << "  reference genome.  It is exremely useful to have read filtering" << std::endl
-       << "  information, and mapping runtime may decrease substantially when a" << std::endl
-       << "  precomputed suffix array index on the reference sequence is" << std::endl
-       << "  specified." << std::endl
-       << "  " << std::endl
-       << "  Although reads may be input in FASTA format, the recommended input is" << std::endl
-       << "  PacBio BAM files because these contain quality value" << std::endl
-       << "  information that is used in the alignment and produces higher quality" << std::endl
-       << "  variant detection." << std::endl
-       << "  Although alignments can be output in various formats, the recommended " << std::endl
-       << "  output format is PacBio BAM." << std::endl
-       << "  Support to bax.h5 and plx.h5 files will be DEPRECATED." << std::endl
-       << "  Support to region tables for h5 files will be DEPRECATED." << std::endl
-       //<< "  Read filtering information is contained in the .bax.h5 input files as" << std::endl
-       //<< "  well as generated by other post-processing programs with analysis of" << std::endl
-       //<< "  pulse files and read in from a separate .region.h5 file.  The current" << std::endl
-       //<< "  set of filters that are applied to reads are high quality region" << std::endl
-       //<< "  filtering, and adapter filtering.  Regions outside high-quality" << std::endl
-       //<< "  regions are ignored in mapping.  Reads that contain regions annotated" << std::endl
-       //<< "  as adapter are split into non-adapter (template) regions, and mapped" << std::endl
-       //<< "  separately." << std::endl
-       << "  " << std::endl
-       << "  When suffix array index of a genome is not specified, the suffix array is" << std::endl
-       << "  built before producing alignment.   This may be prohibitively slow" << std::endl
-       << "  when the genome is large (e.g. Human).  It is best to precompute the" << std::endl
-       << "  suffix array of a genome using the program sawriter, and then specify" << std::endl
-       << "  the suffix array on the command line using -sa genome.fa.sa." << std::endl
-       << "  " << std::endl
-       << "  The optional parameters are roughly divided into three categories:" << std::endl
-       << "  control over anchoring, alignment scoring, and output. " << std::endl
-       << "  " << std::endl
-       << "  The default anchoring parameters are optimal for small genomes and" << std::endl
-       << "  samples with up to 5% divergence from the reference genome.  The main" << std::endl
-       << "  parameter governing speed and sensitivity is the -minMatch parameter." << std::endl
-       << "  For human genome alignments, a value of 11 or higher is recommended.  " << std::endl
-       << "  Several methods may be used to speed up alignments, at the expense of" << std::endl
-       << "  possibly decreasing sensitivity.  " << std::endl
-       << "  " << std::endl
-       //       << "  If the genome is highly repetitive or divergent from the read" << std::endl
-       //       << "  sequences, the value of -maxExpand should be increased.  This option" << std::endl
-       //       << "  controls how much the search for anchors is expanded past a simple" << std::endl
-       //       << "  greedy search.  A value for -maxExpand of 1 is sufficent for" << std::endl
-       //       << "  non-repetitive genomes, and values of -maxExpand greater than 5 are" << std::endl
-       //       << "  not recommended." << std::endl
-       //       << "  " << std::endl
-       << "  Regions that are too repetitive may be ignored during mapping by" << std::endl
-       << "  limiting the number of positions a read maps to with the" << std::endl
-       << "  -maxAnchorsPerPosition option.  Values between 500 and 1000 are effective" << std::endl
-       << "  in the human genome." << std::endl
-       << "  " << std::endl
-       << "  For small genomes such as bacterial genomes or BACs, the default parameters "
-       << std::endl
-       << "  are sufficient for maximal sensitivity and good speed." << std::endl
-       << std::endl
-       << std::endl;
-    return ss.str();
-}
